@@ -24,20 +24,14 @@ from airflow.api_fastapi.common.types import UIAlert
 class ConfigResponse(BaseModel):
     """configuration serializer."""
 
-    navbar_color: str
-    navbar_text_color: str
-    navbar_hover_color: str
-    navbar_text_hover_color: str
     page_size: int
     auto_refresh_interval: int
     hide_paused_dags_by_default: bool
     instance_name: str
-    instance_name_has_markup: bool
     enable_swagger_ui: bool
     require_confirmation_dag_change: bool
     default_wrap: bool
-    warn_deployment_exposure: bool
-    audit_view_excluded_events: str
-    audit_view_included_events: str
     test_connection: str
     dashboard_alert: list[UIAlert]
+    show_external_log_redirect: bool
+    external_log_name: str | None = None
