@@ -18,7 +18,7 @@
 from __future__ import annotations
 
 from fastapi import Depends, HTTPException, status
-from sqlalchemy import and_, func, select
+from sqlalchemy import and_, case, func, select
 
 from airflow.api_fastapi.common.dagbag import DagBagDep
 from airflow.api_fastapi.common.db.common import SessionDep
@@ -39,11 +39,6 @@ def next_run_assets(
     dag_bag: DagBagDep,
     session: SessionDep,
 ) -> dict:
-    dag = dag_bag.get_dag(dag_id)
-
-    if not dag:
-        raise HTTPException(status.HTTP_404_NOT_FOUND, f"can't find dag {dag_id}")
-
     dag_model = DagModel.get_dagmodel(dag_id, session=session)
     if dag_model is None:
         raise HTTPException(status.HTTP_404_NOT_FOUND, f"can't find associated dag_model {dag_id}")
@@ -58,6 +53,12 @@ def next_run_assets(
                 AssetModel.uri,
                 AssetModel.name,
                 func.max(AssetEvent.timestamp).label("lastUpdate"),
+                func.max(
+                    case(
+                        (AssetDagRunQueue.asset_id.is_not(None), 1),
+                        else_=0,
+                    )
+                ).label("queued"),
             )
             .join(DagScheduleAssetReference, DagScheduleAssetReference.asset_id == AssetModel.id)
             .join(
@@ -86,5 +87,9 @@ def next_run_assets(
         )
     ]
 
+    for event in events:
+        if not event.pop("queued", None):
+            event["lastUpdate"] = None
+
     data = {"asset_expression": dag_model.asset_expression, "events": events}
     return data
